@@ -37,13 +37,13 @@ This file is for clutter based gui and it handles config file reading
 /* This is temporary location: move to jammo.h or similar. */
 ClutterActor* jammo_get_actor_by_id(const gchar* id);
 
-char* chum_get_current_song();
-void chum_set_current_song(gchar* song);
+const char* chum_get_current_song();
+void chum_set_current_song(const gchar* song);
 
 int chum_get_state_of_chum();
 void chum_set_state_of_chum(int state);
 
-char* chum_get_selected_language();
+const char* chum_get_selected_language();
 void  chum_set_selected_language(const gchar* language);
 
 void chum_set_duetto(gboolean b);
@@ -51,4 +51,6 @@ gboolean chum_get_duetto();
 
 gboolean chum_is_easy_game();
 void chum_set_easy_game(gboolean b);
+
+void chum_hide_this_tangle_actor (ClutterActor *actor, gpointer none);
 #endif  /*  _CHUM_H_  */
