@@ -13,6 +13,7 @@
 
 #include <tangle.h>
 #include "../meam/jammo-editing-track.h"
+#include "jammo-sample-button.h"
 
 #define JAMMO_TYPE_TRACK_VIEW (jammo_track_view_get_type())
 #define JAMMO_TRACK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), JAMMO_TYPE_TRACK_VIEW, JammoTrackView))
@@ -34,6 +35,9 @@ typedef struct _JammoTrackViewClass {
 
 GType jammo_track_view_get_type(void) G_GNUC_CONST;
 
-ClutterActor* jammo_track_view_new(JammoEditingTrack* track);
+ClutterActor* jammo_track_view_new(JammoEditingTrack* track, guint n_slots, guint64 slot_duration, gfloat slot_size);
+
+void jammo_track_view_add_jammo_sample_button(JammoTrackView* track_view, JammoSampleButton* sample_button, guint slot);
+guint jammo_track_view_get_sample_button_slot(JammoTrackView* track_view, JammoSampleButton* sample_button);
 
 #endif
