@@ -10,6 +10,7 @@
 
 #include <tangle.h>
 #include <clutter/clutter.h>
+#include <unistd.h>
 #include <fcntl.h> //we check some files
 #include "string.h"
 
@@ -21,6 +22,10 @@
 #include "jammo-cursor.h"
 #include "../meam/jammo-playing-track.h"
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <stdio.h>
 static JammoSequencer* singinggame_sequencer = NULL; //used for stopping
 
 
@@ -92,7 +97,10 @@ static void update_trace(ClutterActor *data,int x,int y){
 		}
 
 		cogl_push_draw_buffer();
+		
+		/* TODO: the following memory allocation leaks even if there is unref. */
 		offscreen = cogl_offscreen_new_to_texture(handle);
+
 		g_assert(offscreen != COGL_INVALID_HANDLE);
 		cogl_set_draw_buffer(COGL_OFFSCREEN_BUFFER, offscreen);
 
@@ -150,7 +158,7 @@ void singinggame_start_sequencer(JammoSequencer* sequencer) {
 
 
 static void start_sequencer(JammoMentor* mentor, const gchar* speech, gpointer sequencer){
-	clutter_actor_hide(TANGLE_ACTOR(jammo_mentor_get_default()));
+	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
 	singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
 }
 
@@ -164,15 +172,17 @@ static void song_view_showed(TangleActor *actor, ClutterActorBox *arg1, ClutterA
 
 	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), filepath1, start_sequencer, sequencer);
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "");
+	g_free(filepath1);
 }
 
 
+
 static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointer none) {
 	printf("Sequencer stopped_playback\n");
 
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
-	clutter_container_foreach(CLUTTER_CONTAINER(mainview), tangle_actor_hide_animated, NULL);
+	clutter_container_foreach(CLUTTER_CONTAINER(mainview), chum_hide_this_tangle_actor, NULL);
 	
 	//Go back to songselection
 	ClutterActor* view = jammo_get_actor_by_id("songselection-view");
@@ -187,15 +197,16 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 	//Saving to cupboard and to log.
 	gchar* cmd;
 
-
+	//TODO: save selected_language to filename too
 	//Copy that recorded song to 'singings' and name it.
 	cmd = g_strdup_printf("cp %s/last_recorded.wav %s/%s.wav", JAMMO_DIRECTORY, SINGINGS_DIRECTORY,chum_get_current_song() );
 	if (system(cmd)) 
 		printf("Error, can't call '%s'\n",cmd);
-
+	g_free(cmd);
 
 	//And make it permanent copy for carer/researcher. Filenames look like this: log_singing_2010.02.22_21.16.27.wav
-	cmd = g_strdup_printf("cp %s/last_recorded.wav %s/log_singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav",JAMMO_DIRECTORY,JAMMO_DIRECTORY);
+	//Use mv so it is faster (and last_recorded should not be used anymore)
+	cmd = g_strdup_printf("mv %s/last_recorded.wav %s/log_singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav",JAMMO_DIRECTORY,JAMMO_DIRECTORY);
 	if (system(cmd)) 
 		printf("Error, can't call '%s'\n",cmd);
 
@@ -225,13 +236,13 @@ static void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpoint
 	JammoSequencer* sequencer = jammo_sequencer_new();
 	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped_playback), NULL);
 
-	//TODO: maybe we not should use currently selected_language, but save it too.
 	gchar *filename;
 	int fd;
 	filename = g_strdup_printf("%s/songs/%s/comping%s.ogg", DATA_DIR,chum_get_current_song(),chum_get_selected_language());
 	fd = open(filename,O_RDONLY);
 	if (fd == -1) //File not found
 		{  //no track for this language,. use  common comping.
+		g_free(filename);
 		filename = g_strdup_printf("%s/songs/%s/comping.ogg", DATA_DIR,chum_get_current_song()); //try without language postfix
 		}
 	printf("looking for file '%s' for comping_track\n",filename);
@@ -246,9 +257,27 @@ static void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpoint
 	loaded_filename =  g_strdup_printf("%s/last_recorded.wav",JAMMO_DIRECTORY);
 	printf("looking for file '%s' for loaded_track\n",loaded_filename);	
 
-	JammoPlayingTrack* playing_track2;
-	playing_track2 = jammo_playing_track_new(loaded_filename);
-	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(playing_track2));  
+
+	//Recorded file must be there and it must not be zero sized.
+	struct stat buf;
+	if (stat(loaded_filename, &buf) == -1)
+		{
+		printf("Recorded file '%s' doesn't found\n",loaded_filename);
+		}
+	else
+		{
+		if (buf.st_size == 0)
+			{
+			unlink(loaded_filename);
+			}
+		else
+			{
+			JammoPlayingTrack* playing_track2;
+			playing_track2 = jammo_playing_track_new(loaded_filename);
+			jammo_sequencer_add_track(sequencer, JAMMO_TRACK(playing_track2));
+			}
+		}
+
 	g_free(loaded_filename);
 
 	ClutterColor green = { 0, 255, 0, 128 };
@@ -333,26 +362,28 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 
 	//Do not use pitch_detect on OFFICIAL_RELEASE (not robust enough)
 	#ifndef OFFICIAL_RELEASE
-	gchar* selected_language=chum_get_selected_language();
+	const gchar* selected_language=chum_get_selected_language();
 	gchar *filepath1;
 	//contour_cursor = moving thing
 	contour_cursor = clutter_texture_new();
 	filepath1 = g_strdup_printf("%s/songs/%s/cursor%s.png", DATA_DIR, name, selected_language );
 	fd = open(filepath1,O_RDONLY);
-	if (fd == -1) //File not found
-		{
+	if (fd == -1) {
+		g_free(filepath1);
 		filepath1 = g_strdup_printf("%s/songs/%s/cursor.png", DATA_DIR,name ); //try without language postfix
 		int fd = open(filepath1,O_RDONLY);
-		if (fd == -1) //File not found
-			{
+		if (fd == -1) {
 			printf("file '%s' not found, using default cursor\n",filepath1);
 			//contour_cursor = config_get_configured_actor(NULL,"contour_star");
-			}
-		else
+		} else {
 			clutter_texture_set_from_file (CLUTTER_TEXTURE (contour_cursor), filepath1, NULL);
+			close(fd);
 		}
-	else
+	} else {
 		clutter_texture_set_from_file (CLUTTER_TEXTURE (contour_cursor), filepath1, NULL);
+		close(fd);
+	}
+	g_free(filepath1);
 
 	clutter_container_add_actor (CLUTTER_CONTAINER (view), contour_cursor);
 
@@ -412,13 +443,12 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 
 
 void singinggame_start_songselection(){
-	printf("\n\nDimming\n");
 	//Add transperency to songs which do not have current language vocal-track.
 	//Hide advanced songs, when game level is easy.
 	///////////////////////////////////////////////////////////////////////////////
 	ClutterActor* container = jammo_get_actor_by_id("songselection-all-songs");
-	char* selected_language = chum_get_selected_language();
-	GList* songlist = clutter_container_get_children(CLUTTER_CONTAINER(container));
+	const char* selected_language = chum_get_selected_language();
+	GList* songlist;
 	GList *l;
 
 
@@ -428,9 +458,8 @@ void singinggame_start_songselection(){
 		id_of_actor = clutter_get_script_id(G_OBJECT(l->data));
 		if (id_of_actor==NULL) continue; //In child-list there are many id=NULL actors.
 			
-		if (strncmp(id_of_actor,"songselection-song-",19)==0)
-			{
-			const gchar* name;
+		if (strncmp(id_of_actor,"songselection-song-",19)==0) {
+			gchar* name;
 			g_object_get(l->data, "name", &name, NULL);
 			//printf("name of song: '%s'\n",name);
 			
@@ -454,24 +483,27 @@ void singinggame_start_songselection(){
 				clutter_actor_set_opacity(texture,255); //0=transparency, 255=opaque
 				}
 				
-				//Stupid way to mark these songs to advanced game, FIXME
-				if (chum_is_easy_game() &&
-						(strncmp(id_of_actor,"songselection-song-miska",24)==0 ||
-						strncmp(id_of_actor,"songselection-song-pig",22)==0 ||
-						strncmp(id_of_actor,"songselection-song-avignon",26)==0)  )
-					{
-					//printf("  hide this\n");
-					clutter_actor_hide(button);
-					}
-				else
-					{
-					//printf("  show this\n");
-					clutter_actor_show(button);
-					}
-				
-			
-					
+			//Stupid way to mark these songs to advanced game, FIXME
+			if (chum_is_easy_game() &&
+					(strncmp(id_of_actor,"songselection-song-miska",24)==0 ||
+					strncmp(id_of_actor,"songselection-song-pig",22)==0 ||
+					strncmp(id_of_actor,"songselection-song-avignon",26)==0)  )
+				{
+				//printf("  hide this\n");
+				clutter_actor_hide(button);
+				}
+			else
+				{
+				//printf("  show this\n");
+				clutter_actor_show(button);
+				}
+
+			if (fd != -1) {
+				close(fd);
 			}
+			g_free(filename);
+			g_free(name);
+		}
 	}
 	
 	//Tune size of container
@@ -519,7 +551,7 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 	gchar *new_name;
 	new_name =  g_strdup_printf("_%s", name);
 	handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), (gpointer)new_name);
-	
+	g_free(new_name);
 	
 	ClutterActor* button;
 	ClutterActor* texture;
