@@ -1,10 +1,24 @@
 #ifndef __PM_STORAGEAGENT_H_
 #define __PM_STORAGEAGENT_H_
 
+#define JAMMOPROFILE ".jammo-profiles/"
+#define PROFILETYPE ".csv"
+
+// Profile parameters
+#define PROF_PARAM_USERID "userID"
+#define PROF_PARAM_USERNAME "username"
+#define PROF_PARAM_AUTHLEVEL "authLevel"
+#define PROF_PARAM_FIRSTNAME "firstName"
+#define PROF_PARAM_LASTNAME "lastName"
+#define PROF_PARAM_POINTS "gamePoints"
+#define PROF_PARAM_AGE "age"
+
 #ifdef __cplusplus
 
 #include <map>
 #include <iostream>
+#include <vector>
+#include <iterator>
 
 using namespace std;
 
@@ -31,10 +45,10 @@ public:
 	string getDetails();
 	
 	// Gets one detail
-	string getDetail(string detail);
+	string getDetail(string& detail);
 	
 	// Set a detail
-	bool setDetails(string detail, string newvalue);
+	bool setDetails(string& detail, string& newvalue);
 	
 	// Clear all the user details
 	bool clearDetails();
@@ -45,6 +59,11 @@ private:
 	map<string, string> profileDetails;
 	map<string, string>::const_iterator profileIterator;
 	
+	// This function removes the unneccesary symbols
+	// From the lines read
+	void Tokenize(const string& str,
+			  vector<string>& tokens,
+			  const string& delimiters);
 };
 
 #endif //__cplusplus
