@@ -3,7 +3,7 @@
  *
  * This file is part of JamMo.
  *
- * (c) 2009 University of Oulu
+ * (c) 2009-2010 University of Oulu
  *
  * Authors: Henrik Hedberg <henrik.hedberg@oulu.fi>
  */
@@ -27,3 +27,7 @@ void jammo_meam_init(int* argc, char** argv[]) {
 	gst_element_register(NULL, "jammosampler", 0, GST_TYPE_JAMMO_SAMPLER);
 	gst_element_register(NULL, "jammoslider", 0, GST_TYPE_JAMMO_SLIDER);
 }
+
+void jammo_meam_cleanup(void) {
+	gst_deinit();
+}
